@@ -5,6 +5,7 @@ from .CxPortalWebService import (
     delete_preset,
     export_preset,
     export_queries,
+    get_compare_scan_results,
     get_import_queries_status,
     get_path_comments_history,
     get_user_profile_data,
@@ -13,6 +14,8 @@ from .CxPortalWebService import (
     get_query_id_by_language_group_and_query_name,
     get_name_of_user_who_marked_false_positive_from_comments_history,
     get_preset_list,
+    get_result_path,
+    get_results_for_scan,
     get_server_license_data,
     get_server_license_summary,
     delete_project,
